//BUDP_AC_869x_var.inc

/*******************************************************************************/
/*****	Device   ***************************************************************/
/*******************************************************************************/


VARIABLE phys_DEVICE_MAN_ID
{
	LABEL		[phys_device_man_id];
	HELP		[phys_device_man_id_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	120;
		{ 120, [Buerkert_neu]				},
		{ 250, [not_used]					},
		{ 251, [none]						},
		{ 252, [unknown]					},
		{ 253, [special]					}
	}
	HANDLING	READ;
}

VARIABLE phys_IDENT_NUMBER
{
	LABEL		[phys_ident_number];
	HELP		[phys_ident_number_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{ 0, "C630"	}
	}
	HANDLING	READ;
}

VARIABLE phys_tag_desc
{
	LABEL		[tag_desc];
	HELP		[tag_desc_help];
	CLASS		LOCAL;
	TYPE		ASCII (32)
	{
		DEFAULT_VALUE [buerkert_8692_8693];
	}
	HANDLING	READ ;/* & WRITE; */
}

/************************************************************************/
/***	[Params]	*************************************************/
/************************************************************************/

VARIABLE ERROR_8692_8693
{
	LABEL         [txt_ERROR];
	HELP          [txt_help_ERROR];
	CLASS         CONTAINED;
	TYPE INTEGER(1)
	{
		MIN_VALUE 0;
		MAX_VALUE 255;
		DEFAULT_VALUE 0;
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

VARIABLE MODE1
{
	LABEL         [txt_MODE];
	HELP          [txt_help_MODE];
	CLASS         CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 0;
			{ 0,	[mode_AUTO]			},
			{ 1,	[mode_MAN]			},
			{ 12,	[mode_SAFE]			}
	}
	HANDLING READ & WRITE;
	POST_WRITE_ACTIONS
	{
		DEFINITION
		{
			   ACKNOWLEDGE([refresh_download]);
		}
	}
}

VARIABLE DIAGNOSIS
{
	LABEL		[txt_DIAGNOSIS];
	HELP        [txt_help_DIAGNOSIS];
	CLASS		CONTAINED & DYNAMIC;
	STYLE		"MULTILINE 16 17" ;
	TYPE  BIT_ENUMERATED (4)
	{
		  DEFAULT_VALUE				0x00000000;
		  { DIA_HW_ELECTR,			[dia_HW_ELECTR],				[dia_HW_ELECTR_help]			},
		  { DIA_HW_MECH,			[dia_HW_MECH],					[dia_HW_MECH_help]				},
		  { DIA_TEMP_MOTOR,			[dia_TEMP_MOTOR],				[dia_TEMP_MOTOR_help]			},
		  { DIA_TEMP_ELECTR,		[dia_TEMP_ELECTR],				[dia_TEMP_ELECTR_help]			},
		  { DIA_MEM_CHKSUM,			[dia_MEM_CHKSUM],				[dia_MEM_CHKSUM_help]			},
		  { DIA_MEASUREMENT,		[dia_MEASUREMENT],				[dia_MEASUREMENT_help]			},
		  { DIA_NOT_INIT,			[dia_NOT_INIT],					[dia_NOT_INIT_help]				},
		  { DIA_INIT_ERR,			[dia_INIT_ERR],					[dia_INIT_ERR_help]				},
		  { DIA_ZERO_ERR,			[dia_ZERO_ERR],					[dia_ZERO_ERR_help]				},
		  { DIA_SUPPLY,				[dia_SUPPLY],					[dia_SUPPLY_help]				},
		  { DIA_CONF_INVAL,			[dia_CONF_INVAL],				[dia_CONF_INVAL_help]			},
		  { DIA_WARMSTART,			[dia_WARMSTART],				[dia_WARMSTART_help]			},
		  { DIA_COLDSTART,			[dia_COLDSTART],				[dia_COLDSTART_help]			},
		  { DIA_MAINTENANCE,		[dia_MAINTENANCE],				[dia_MAINTENANCE_help]			},
		  { DIA_CHARACT,			[dia_CHARACT],					[dia_CHARACT_help]				},
		  { DIA_IDENT_VIOL,			[dia_IDENT_VIOL],				[dia_IDENT_VIOL_help]			},
		  { EXTENSION_AVAILABLE,	[dia_EXTENSION_AVAILABLE],		[dia_EXTENSION_AVAILABLE_help]	}
	}
	HANDLING READ;
}


VARIABLE FACTORY_RESET
{
	LABEL         [txt_FACTORY_RESET];
	HELP          [txt_help_FACTORY_RESET];
	CLASS         CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 0;
		{	0,	[no_function]		},
		{	1,	[warmstart]			},
		{	2,	[factory_reset]		}
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

VARIABLE ACT_STROKE_TIME_INC
{
	LABEL         [txt_ACT_STROKE_TIME_INC];
	HELP          [txt_help_ACT_STROKE_TIME_INC];
	CLASS         CONTAINED;
	CONSTANT_UNIT [sec_40];
	TYPE INTEGER(2)
	{
		MIN_VALUE 0;
		MAX_VALUE 65535;
		DEFAULT_VALUE 1;
		DISPLAY_FORMAT	".3f";
	}
	HANDLING READ;
	PRE_EDIT_ACTIONS
	{
		ACT_STROKE_TIME_INC_PreEdit
	}
}

ACT_STROKE_TIME_INC_2 LIKE VARIABLE ACT_STROKE_TIME_INC
{
	REDEFINE TYPE FLOAT;
}

VARIABLE ACT_STROKE_TIME_INC_LOC
{
	LABEL         [txt_ACT_STROKE_TIME_INC_40];
	HELP          [txt_help_ACT_STROKE_TIME_INC_40];
	CLASS         CONTAINED;
	CONSTANT_UNIT [sec];
	TYPE FLOAT
	{
		DISPLAY_FORMAT	".3f";
	}
	HANDLING READ;
}

METHOD ACT_STROKE_TIME_INC_PreEdit
{
	LABEL [txt_ACT_STROKE_TIME_INC];

	DEFINITION
	{
		ACT_STROKE_TIME_INC_2	= ACT_STROKE_TIME_INC;
		ACT_STROKE_TIME_INC_LOC = (ACT_STROKE_TIME_INC_2 / 40);
	}
}

VARIABLE ACT_STROKE_TIME_DEC
{
	LABEL         [txt_ACT_STROKE_TIME_DEC];
	HELP          [txt_help_ACT_STROKE_TIME_DEC];
	CLASS         CONTAINED;
	CONSTANT_UNIT [sec_40];
	TYPE INTEGER(2)
	{
		MIN_VALUE 0;
		MAX_VALUE 65535;
		DEFAULT_VALUE 1;
		DISPLAY_FORMAT	".3f";
	}
	HANDLING READ;
	PRE_EDIT_ACTIONS
	{
		ACT_STROKE_TIME_DEC_PreEdit
	}
}

ACT_STROKE_TIME_DEC_2 LIKE VARIABLE ACT_STROKE_TIME_DEC
{
	REDEFINE TYPE FLOAT;
}

VARIABLE ACT_STROKE_TIME_DEC_LOC
{
	LABEL         [txt_ACT_STROKE_TIME_DEC_40];
	HELP          [txt_help_ACT_STROKE_TIME_DEC_40];
	CLASS         CONTAINED;
	CONSTANT_UNIT [sec];
	TYPE FLOAT
	{
		DISPLAY_FORMAT	".3f";
	}
	HANDLING READ;
}

METHOD ACT_STROKE_TIME_DEC_PreEdit
{
	LABEL [txt_ACT_STROKE_TIME_DEC];

	DEFINITION
	{
		ACT_STROKE_TIME_DEC_2	= ACT_STROKE_TIME_DEC;
		ACT_STROKE_TIME_DEC_LOC = (ACT_STROKE_TIME_DEC_2 / 40);
	}
}

VARIABLE DEADBAND
{
	LABEL         [txt_DEADBAND];
	HELP          [txt_help_DEADBAND];
	CLASS         CONTAINED;
	CONSTANT_UNIT [txt_0_1_proc];
	TYPE INTEGER(2)
	{
		MIN_VALUE 1;
		MAX_VALUE 50;
		DEFAULT_VALUE 10;
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

VARIABLE LIN_TYPE
{
	LABEL         [txt_LIN_TYPE];
	HELP          [txt_help_LIN_TYPE];
	CLASS         CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 0;
		{	0,	[Linear]						},
		{	1,	[Equal_percentage_1_25]			},
		{	2,	[Equal_percentage_1_33]			},
		{	3,	[Equal_percentage_1_50]			},
		{	4,	[Equal_perc_inverse_1_25]		},
		{	5,	[Equal_perc_inverse_1_33]		},
		{	6,	[Equal_perc_inverse_1_50]		},
		{	7,	[User_defined]					}
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

VARIABLE SELF_CALIB_CMD
{
	LABEL         [txt_SELF_CALIB_CMD];
	HELP          [txt_help_SELF_CALIB_CMD];
	CLASS         CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 0;
		{	0,	[No_Function]		},
		{	1,	[Start_Autotune]	}
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

VARIABLE SERVO_GAIN_1
{
	LABEL         [txt_SERVO_GAIN_1];
	HELP          [txt_help_SERVO_GAIN_1];
	CLASS         CONTAINED;
	TYPE INTEGER(2)
	{
		MIN_VALUE 1;
		MAX_VALUE 9999;
		DEFAULT_VALUE 1;
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

VARIABLE SERVO_GAIN_2
{
	LABEL         [txt_SERVO_GAIN_2];
	HELP          [txt_help_SERVO_GAIN_2];
	CLASS         CONTAINED;
	TYPE INTEGER(2)
	{
		MIN_VALUE 1;
		MAX_VALUE 9999;
		DEFAULT_VALUE 1;
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

VARIABLE SETP_CUTOFF_DEC
{
	LABEL         [txt_SETP_CUTOFF_DEC];
	HELP          [txt_help_SETP_CUTOFF_DEC];
	CLASS         CONTAINED;
	CONSTANT_UNIT [proc];
	TYPE INTEGER(2)
	{
		MIN_VALUE 0;
		MAX_VALUE 25;
		DEFAULT_VALUE 0;
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

VARIABLE SETP_CUTOFF_INC
{
	LABEL         [txt_SETP_CUTOFF_INC];
	HELP          [txt_help_SETP_CUTOFF_INC];
	CLASS         CONTAINED;
	CONSTANT_UNIT [proc];
	TYPE INTEGER (2)
	{
		MIN_VALUE 75;
		MAX_VALUE 100;
		DEFAULT_VALUE 100;
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

VARIABLE TRAVEL_LIMIT_LOW
{
	LABEL         [txt_TRAVEL_LIMIT_LOW];
	HELP          [txt_help_TRAVEL_LIMIT_LOW];
	CLASS         CONTAINED;
	CONSTANT_UNIT [proc];
	TYPE INTEGER(2)
	{
		MIN_VALUE 0;
		MAX_VALUE 50;
		DEFAULT_VALUE 0;
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
	PRE_EDIT_ACTIONS
	{
		TRAVEL_LIMIT_LOW_PreEdit
	}

	POST_EDIT_ACTIONS
	{
		TRAVEL_LIMIT_LOW_PostEdit
	}
}

VARIABLE TRAVEL_LIMIT_LOW_Loc
{
	LABEL		[func1_AI_channel_Loc];
	CLASS		LOCAL;
	TYPE		INTEGER(2);
}

METHOD TRAVEL_LIMIT_LOW_PreEdit
{
	LABEL [Save_Channel_PreEdit];

	DEFINITION
	{
		TRAVEL_LIMIT_LOW_Loc = TRAVEL_LIMIT_LOW;
	}
}

METHOD TRAVEL_LIMIT_LOW_PostEdit
{
	LABEL [Set_Channel_PostEdit];

	DEFINITION
	{
		if (TRAVEL_LIMIT_LOW_Loc != TRAVEL_LIMIT_LOW)
		{
			if ((TRAVEL_LIMIT_UP - TRAVEL_LIMIT_LOW) < 50)
			{
				TRAVEL_LIMIT_UP = (TRAVEL_LIMIT_LOW + 50);
			}
			else
			{
				TRAVEL_LIMIT_UP = TRAVEL_LIMIT_UP;
			}
		}
	}
}

VARIABLE TRAVEL_LIMIT_UP
{
	LABEL         [txt_TRAVEL_LIMIT_UP];
	HELP          [txt_help_TRAVEL_LIMIT_UP];
	CLASS         CONTAINED;
	CONSTANT_UNIT [proc];
	TYPE INTEGER(2)
	{
		MIN_VALUE 50;
		MAX_VALUE 100;
		DEFAULT_VALUE 100;
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
	PRE_EDIT_ACTIONS
	{
		TRAVEL_LIMIT_UP_PreEdit
	}

	POST_EDIT_ACTIONS
	{
		TRAVEL_LIMIT_UP_PostEdit
	}
}

VARIABLE TRAVEL_LIMIT_UP_Loc
{
	LABEL		[TRAVEL_LIMIT_UP_Loc];
	CLASS		LOCAL;
	TYPE		INTEGER(2);
}

METHOD TRAVEL_LIMIT_UP_PreEdit
{
	LABEL [Save_TRAVEL_LIMIT_UP_PreEdit];

	DEFINITION
	{
		TRAVEL_LIMIT_UP_Loc = TRAVEL_LIMIT_UP;
	}
}

METHOD TRAVEL_LIMIT_UP_PostEdit
{
	LABEL [Set_TRAVEL_LIMIT_UP_PostEdit];

	DEFINITION
	{
		if (TRAVEL_LIMIT_UP_Loc != TRAVEL_LIMIT_UP)
		{
			if ((TRAVEL_LIMIT_UP - TRAVEL_LIMIT_LOW) < 50)
			{
				TRAVEL_LIMIT_LOW = (TRAVEL_LIMIT_UP - 50);
			}
			else
			{
				TRAVEL_LIMIT_LOW = TRAVEL_LIMIT_LOW;
			}
		}
	}
}

VARIABLE TRAVEL_RATE_DEC
{
	LABEL         [txt_TRAVEL_RATE_DEC];
	HELP          [txt_help_TRAVEL_RATE_DEC];
	CLASS         CONTAINED;
	CONSTANT_UNIT [txt_0_1_s];
	TYPE INTEGER(2)
	{
		MIN_VALUE 10;
		MAX_VALUE 600;
		DEFAULT_VALUE 10;
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

VARIABLE TRAVEL_RATE_INC
{
	LABEL         [txt_TRAVEL_RATE_INC];
	HELP          [txt_help_TRAVEL_RATE_INC];
	CLASS         CONTAINED;
	CONSTANT_UNIT [txt_0_1_s];
	TYPE INTEGER(2)
	{
		MIN_VALUE 10;
		MAX_VALUE 600;
		DEFAULT_VALUE 10;
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

VARIABLE POSITIONING_VALUE
{
	LABEL         [txt_POSITIONING_VALUE];
	HELP          [txt_help_POSITIONING_VALUE];
	CLASS           CONTAINED & DYNAMIC;
	CONSTANT_UNIT [txt_0_1_proc];
	TYPE INTEGER(2)
	{
		MIN_VALUE 0;
		MAX_VALUE 1000;
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
}

VARIABLE FEEDBACK_VALUE
{
	LABEL         [txt_FEEDBACK_VALUE];
	HELP          [txt_help_FEEDBACK_VALUE];
	CLASS           CONTAINED & DYNAMIC;
	CONSTANT_UNIT [txt_0_1_proc];
	TYPE INTEGER(2)
	{
		MIN_VALUE -9999;
		MAX_VALUE 9999;
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
}

VARIABLE SETP_DEVIATION
{
	LABEL         [txt_SETP_DEVIATION];
	HELP          [txt_help_SETP_DEVIATION];
	CLASS         CONTAINED;
	CONSTANT_UNIT [txt_0_1_proc];
	TYPE INTEGER(2)
	{
		MIN_VALUE -9999;
		MAX_VALUE 9999;
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
}

VARIABLE INCREASE_CLOSE
{
	LABEL         [txt_INCREASE_CLOSE];
	HELP          [txt_help_INCREASE_CLOSE];
	CLASS         CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 0;
		{	0,	[Rising]	},
		{	1,	[Falling]	}
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

VARIABLE SP
{
	LABEL         [txt_SP];
	HELP          [txt_help_SP];
	CLASS         CONTAINED;
	TYPE INTEGER(2)
	{
		MIN_VALUE -999;
		MAX_VALUE 9999;
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
}

VARIABLE PV
{
	LABEL         [txt_PV];
	HELP          [txt_help_PV];
	CLASS         CONTAINED;
	TYPE INTEGER(2)
	{   
		DEFAULT_VALUE   0.0;
		MIN_VALUE		-999;
		MAX_VALUE		9999;
	}
	HANDLING READ;
}

VARIABLE TEMP
{
	LABEL         [txt_TEMP];
	HELP          [txt_help_TEMP];
	CLASS         CONTAINED;
	CONSTANT_UNIT [txt_0_1_C];
	TYPE INTEGER(2)
	{   
		DEFAULT_VALUE   0.0;
		MIN_VALUE		-550;
		MAX_VALUE		1250;
	}
	HANDLING READ;
}

VARIABLE DBDp
{
	LABEL         [txt_DBDp];
	HELP          [txt_help_DBDp];
	CLASS         CONTAINED;
	CONSTANT_UNIT [txt_0_1_proc];
	TYPE INTEGER(2)
	{   
		DEFAULT_VALUE   10;
		MIN_VALUE		1;
		MAX_VALUE		50;
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

VARIABLE KP
{
	LABEL         [txt_KP];
	HELP          [txt_help_KP];
	CLASS         CONTAINED;
	CONSTANT_UNIT [txt_0_01];
	TYPE INTEGER(2)
	{   
		DEFAULT_VALUE   100;
		MIN_VALUE		0;
		MAX_VALUE		9999;
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

VARIABLE TN
{
	LABEL         [txt_TN];
	HELP          [txt_help_TN];
	CLASS         CONTAINED;
	CONSTANT_UNIT [txt_0_1_s];
	TYPE INTEGER(2)
	{   
		DEFAULT_VALUE   9999;
		MIN_VALUE		5;
		MAX_VALUE		9999;
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

VARIABLE TV
{
	LABEL         [txt_TV];
	HELP          [txt_help_TV];
	CLASS         CONTAINED;
	CONSTANT_UNIT [txt_0_1_s];
	TYPE INTEGER(2)
	{   
		DEFAULT_VALUE   0;
		MIN_VALUE		0;
		MAX_VALUE		9999;
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

VARIABLE X0
{
	LABEL         [txt_X0];
	HELP          [txt_help_X0];
	CLASS         CONTAINED;
	CONSTANT_UNIT [txt_0_1_proc];
	TYPE INTEGER(2)
	{   
		DEFAULT_VALUE   0;
		MIN_VALUE		0;
		MAX_VALUE		1000;
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

VARIABLE mPCONsetp
{
	LABEL         [txt_mPCONsetp];
	HELP          [txt_help_mPCONsetp];
	CLASS         CONTAINED;
	TYPE		  ENUMERATED(2)
	{
		DEFAULT_VALUE 0;
		{	0,	[internal]		},
		{	1,	[external]	}
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

VARIABLE mPCONinp
{
	LABEL         [txt_mPCONinp];
	HELP          [txt_help_mPCONinp];
	CLASS         CONTAINED;
	TYPE		  ENUMERATED(2)
	{
//		{	0,	[P1_P2]		},
		{	1,	[mA_4_20]	},
		{	2,	[Frequency]	},
		{	3,	[Pt_100]	}
	}
	HANDLING READ;
	PRE_EDIT_ACTIONS
	{
			mPCONinp_PreEdit
	}

	POST_EDIT_ACTIONS
	{
			mPCONinp_PostEdit
	}
}

VARIABLE mPCONinp_Loc
{
	LABEL		[mPCONinp_Loc];
	CLASS		LOCAL;
	TYPE		  ENUMERATED(2)
	{
//		{	0,	[P1_P2]		},
		{	1,	[mA_4_20]	},
		{	2,	[Frequency]	},
		{	3,	[Pt_100]	}
	}
}

METHOD mPCONinp_PreEdit
{
	LABEL [Save_mPCONinp_PreEdit];

	DEFINITION
	{
		mPCONinp_Loc = mPCONinp;
	}
}


METHOD mPCONinp_PostEdit
{
	LABEL [Set_mPCONinp_PostEdit];

	DEFINITION
	{
                int status;

		if (mPCONinp_Loc != mPCONinp)
		{
			status = ReadCommand(read_SCALunit);        
		}
	}
}

VARIABLE FTfgPV
{
	LABEL         [txt_FTfgPV];
	HELP          [txt_help_FTfgPV];
	CLASS         CONTAINED;
	TYPE INTEGER(2)
	{   
		DEFAULT_VALUE   0;
		MIN_VALUE		0;
		MAX_VALUE		9;
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

VARIABLE SCALunit
{
	LABEL         [txt_SCALunit];
	HELP          [txt_help_SCALunit];
	CLASS         CONTAINED;
	TYPE		  ENUMERATED(2)
	{
		DEFAULT_VALUE 0;

		IF (mPCONinp == 2)
		{
			{	0,	[l_s]		},
			{	1,	[l_min]		},
			{	2,	[l_h]		},
			{	3,	[CuMtr_min]	},
			{	4,	[CuMtr_h]	},			//Beim Setzen von FMRpvmode auf 0, SCALunit automatisch auf 4 setzen,
			{	5,	[mueg_s]	},
			{	6,	[mueg_min]	},
			{	7,	[mueg_h]	},
			{	8,	[ig_s]		},
			{	9,	[ig_min]	},
			{	10,	[ig_h]		}
		}
		ELSE 
		{
			IF (mPCONinp == 3)		
			{
				{	11,	[unit_1001]	},		//C
				{	12,	[unit_1002]	}		//F
			}
			ELSE 
				{
				{	0,	[l_s]		},
				{	1,	[l_min]		},
				{	2,	[l_h]		},
				{	3,	[CuMtr_min]	},
				{	4,	[CuMtr_h]	},
				{	5,	[mueg_s]	},
				{	6,	[mueg_min]	},
				{	7,	[mueg_h]	},
				{	8,	[ig_s]		},
				{	9,	[ig_min]	},
				{	10,	[ig_h]		},
				{	11,	[unit_1001]	},		//C
				{	12,	[unit_1002]	},		//F
				{	13,	[m_s]		}		//beim Setzen von FMRpvmode auf 1, SCALunit automatisch auf 13 setzen
				{	14,	[unit_1137]	},		//bar
				{	15,	[unit_1138]	},		//mbar
				{	16,	[unit_1141]	},		//psi
				{	17,	[unit_1342]	},		//%
				{	18,	[unit_1013]	},		//mm
				{	19,	[unit_1010]	},		//m
				{	20,	[unit_1038]	},		//l
				{	21,	[without_unit]	}	//ohne Einheit
			}
		}

	}
	HANDLING
		IF ((MODE1 == 0 || MODE1 == 1) && (mPCONinp == 2 || mPCONinp == 3))
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}
//Bei mPCONinp==0							SCALunit nicht vom Bus verndert werden, d.h. schreibgeschtzt
//Bei mPCONinp==1							SCALunit nicht vom Bus verndert werden, d.h. schreibgeschtzt
//if (mPCONinp==2, d.h. Frequenzeingang)	SCALunit = 0..10   zulssig
//if (mPCONinp==3, d.h. Pt-100 Eingang  )	SCALunit = 11..12   zulssig

VARIABLE SCALdp
{
	LABEL         [txt_SCALdp];
	HELP          [txt_help_SCALdp];
	CLASS         CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	1;
		{	0,   "0"		},
		{	1,   "1"		},
		{	2,   "2"		},
		{	3,   "3"		}
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
	PRE_EDIT_ACTIONS
	{
		SCALdp_PreEdit
	}
}

VARIABLE SCALdp_LOC
{
	LABEL         [txt_SCALdp];
	HELP          [txt_help_SCALdp];
	CLASS         CONTAINED;
	TYPE		INTEGER (2);
	HANDLING READ;
}

METHOD SCALdp_PreEdit
{
	LABEL [Save_SCALdp_PreEdit];

	DEFINITION
	{
		if (SCALdp == 0)
		{
			SCALdp_LOC = 1;
		}
		else 
		{
			if (SCALdp == 1)
			{
				SCALdp_LOC = 10;
			}
			else
			{
				if (SCALdp == 2)
				{
					SCALdp_LOC = 100;
				}
				else
					if (SCALdp == 3)
					{
						SCALdp_LOC = 1000;
					}
			}
		}
		PVmin_2 = PVmin;
		PVmin_Loc = (PVmin_2/SCALdp_LOC);
		PVmax_2 = PVmax;
		PVmax_Loc = (PVmax_2/SCALdp_LOC);
		SPmin_2 = SPmin;
		SPmin_Loc = (SPmin_2/SCALdp_LOC);
		SPmax_2 = SPmax;
		SPmax_Loc = (SPmax_2/SCALdp_LOC);

	}
}

VARIABLE PVmin
{
	LABEL         [txt_PVmin];
	HELP          [txt_help_PVmin];
	CLASS         CONTAINED;
	TYPE INTEGER(2)
	{   
		DEFAULT_VALUE   0;
		MIN_VALUE		-999;
		MAX_VALUE		9999;
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

PVmin_2 LIKE VARIABLE PVmin
{
	REDEFINE TYPE FLOAT;
}

VARIABLE PVmin_Loc
{
	LABEL         [txt_PVmin_LOC];
	HELP          [txt_help_PVmin_LOC];
	CLASS         CONTAINED;
	TYPE FLOAT
	{   
		DISPLAY_FORMAT	DEF_DISPLAY_FORMAT_PV_SP(PVmin_Loc)
	}
	HANDLING READ;
}

VARIABLE PVmax
{
	LABEL         [txt_PVmax];
	HELP          [txt_help_PVmax];
	CLASS         CONTAINED;
	TYPE INTEGER(2)
	{   
		DEFAULT_VALUE   1000;
		MIN_VALUE		-999;
		MAX_VALUE		9999;
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

PVmax_2 LIKE VARIABLE PVmax
{
	REDEFINE TYPE FLOAT;
}

VARIABLE PVmax_Loc
{
	LABEL         [txt_PVmax_LOC];
	HELP          [txt_help_PVmax_LOC];
	CLASS         CONTAINED;
	TYPE FLOAT
	{   
		DISPLAY_FORMAT	DEF_DISPLAY_FORMAT_PV_SP(PVmax_Loc)
	}
	HANDLING READ;
}

VARIABLE SPmin
{
	LABEL         [txt_SPmin];
	HELP          [txt_help_SPmin];
	CLASS         CONTAINED;
	TYPE INTEGER(2)
	{   
		DEFAULT_VALUE   0;
		MIN_VALUE		-999;
		MAX_VALUE		9999;
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

SPmin_2 LIKE VARIABLE SPmin
{
	REDEFINE TYPE FLOAT;
}

VARIABLE SPmin_Loc
{
	LABEL         [txt_SPmin_LOC];
	HELP          [txt_help_SPmin_LOC];
	CLASS         CONTAINED;
	TYPE FLOAT
	{   
		DISPLAY_FORMAT	DEF_DISPLAY_FORMAT_PV_SP(SPmin_Loc)
	}
	HANDLING READ;
}

VARIABLE SPmax
{
	LABEL         [txt_SPmax];
	HELP          [txt_help_SPmax];
	CLASS         CONTAINED;
	TYPE INTEGER(2)
	{   
		DEFAULT_VALUE   1000;
		MIN_VALUE		-999;
		MAX_VALUE		9999;
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

SPmax_2 LIKE VARIABLE SPmax
{
	REDEFINE TYPE FLOAT;
}

VARIABLE SPmax_Loc
{
	LABEL         [txt_SPmax_LOC];
	HELP          [txt_help_SPmax_LOC];
	CLASS         CONTAINED;
	TYPE FLOAT
{   
		DISPLAY_FORMAT	DEF_DISPLAY_FORMAT_PV_SP(SPmax_Loc)
	}
	HANDLING READ;
}

VARIABLE mCUTOFFtype
{
	LABEL         [txt_mCUTOFFtype];
	HELP          [txt_help_mCUTOFFtype];
	CLASS         CONTAINED;
	TYPE		  ENUMERATED(2)
	{
		DEFAULT_VALUE 0;
		{	0,	[Process_Value]	},
		{	1,	[Position]		}
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

VARIABLE mBUSfail_func
{
	LABEL         [txt_mBUSfail_func];
	HELP          [txt_help_mBUSfail_func];
	CLASS         CONTAINED;
	TYPE		  ENUMERATED(2)
	{
		DEFAULT_VALUE 0;
		{	0,	[Deactivated]	},
		{	1,	[Activated]		}
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

VARIABLE mERRpinp_func
{
	LABEL         [txt_mERRpinp_func];
	HELP          [txt_help_mERRpinp_func];
	CLASS         CONTAINED;
	TYPE		  ENUMERATED(2)
	{
		DEFAULT_VALUE 0;
		{	0,	[Deactivated]	},
		{	1,	[Activated]		}
	}
	HANDLING
		IF ((MODE1 == 0 || MODE1 == 1 ) && (mPCONinp == 0 || mPCONinp == 1 || mPCONinp == 3))
		{
			READ & WRITE;
		}
		ELSE
		{
			READ;
		}
}		//if (mPCONinp==2)  drfen diese Parameter nicht verndert werden, d.h. schreibgeschtzt

VARIABLE mSPOSpinp_func
{
	LABEL         [txt_mSPOSpinp_func];
	HELP          [txt_help_mSPOSpinp_func];
	CLASS         CONTAINED;
	TYPE		  ENUMERATED(2)
	{
		DEFAULT_VALUE 0;
		{	0,	[Deactivated]	},
		{	1,	[Activated]		}
	}
	HANDLING
		IF ((MODE1 == 0 || MODE1 == 1 ) && (mPCONinp == 0 || mPCONinp == 1 || mPCONinp == 3))
		{
			READ & WRITE;
		}
		ELSE
		{
			READ;
		}
}		//if (mPCONinp==2)  drfen diese Parameter nicht verndert werden, d.h. schreibgeschtzt

VARIABLE mSAFEpos
{
	LABEL         [txt_mSAFEpos];
	HELP          [txt_help_mSAFEpos];
	CLASS         CONTAINED;
	CONSTANT_UNIT [proc];
	TYPE INTEGER(2)
	{   
		DEFAULT_VALUE   0;
		MIN_VALUE		-1;
		MAX_VALUE		100;
	}
	HANDLING
		IF (MODE1 == 0 || MODE1 == 1)
		{
			READ & WRITE;
		}
		ELSE 
		{
			READ;
		}
}

VARIABLE PCON
{
	LABEL         [txt_PCON];
	HELP          [txt_help_PCON];
	CLASS         CONTAINED;
	TYPE		  ENUMERATED(1)
	{
		DEFAULT_VALUE 0;
		{	0,	[Deactivated]	},
		{	1,	[Activated]		}
	}
	HANDLING
		IF (MODE1 == 0)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}	// Schreiben nur mglich, wenn  MODE1=0 , d.h. Automatikbetrieb ist.

VARIABLE XTUNE_STATUS
{
	LABEL         [txt_XTUNE_STATUS];
	HELP          [txt_help_XTUNE_STATUS];
	CLASS         CONTAINED;
	TYPE		  UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE	0;
		{ 0, [TUNE_ok] },
		{ 1, [TUNE_ERROR] },
	}
	HANDLING READ;
}

VARIABLE para_XTUNE_STATUS
{
	LABEL         [txt_XTUNE_STATUS];
	HELP          [txt_help_XTUNE_STATUS];
	CLASS         CONTAINED;
	TYPE		  UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE	0;
		{ 0, [TUNE_ok] },

	}
	HANDLING READ;
}

VARIABLE limit_min
{
        LABEL "limit_0";
        CLASS LOCAL;
        TYPE  INTEGER (2)
        {
                DEFAULT_VALUE -20;
        }
}

VARIABLE limit_max
{
        LABEL "limit_0";
        CLASS LOCAL;
        TYPE  INTEGER (2)
        {
                DEFAULT_VALUE 150;
        }
}

VARIABLE limit_min_2
{
        LABEL "limit_0";
        CLASS LOCAL;
        TYPE  INTEGER (2)
        {
                DEFAULT_VALUE -9999;
        }
}

VARIABLE limit_max_2
{
        LABEL "limit_0";
        CLASS LOCAL;
        TYPE  INTEGER (2)
        {
                DEFAULT_VALUE 9999;
        }
}