/*----------------------------------------------------------------------*/
/*      Copyright (C) Brkert Werke GmbH   All Rights Reserved          */
/*      Product:        SIMATIC PDM                                     */
/*                                                                      */
/*      Device:         SideControl Type 8792 and 8793 PROFIBUS DP      */
/*      Description:    Device Description                              */
/*      Dictionary:     BUDP_AC_879x.dct                                */
/*                                                                      */
/*      Revision History:                                               */
/*      1.00 - first revision                                           */
/*      2.00 - bugfix for TRAVEL_RATE_INC and TRAVEL_RATE_DEC:          */
/*             unit is 0.1 s and range is 10 to 600                     */
/*----------------------------------------------------------------------*/

// BUDP_AC_879x.ddl

MANUFACTURER    120,    // Brkert, entspricht 0x78
DEVICE_TYPE     2,      // Actuator
DEVICE_REVISION 0x0100,
DD_REVISION     2

#include "SI_FileM.inc"
#include "SI_OptM.inc"
#include "SI_HlpM.inc"
#include "SI_ViewM.inc"

#define DEVICE_TITLE [menu_table_actor_buerkert_8792_8793]

#define DIA_HW_ELECTR			0x01000000  // 0x00000001 
#define DIA_HW_MECH				0x02000000  // 0x00000002 
#define DIA_TEMP_MOTOR			0x04000000  // 0x00000004 
#define DIA_TEMP_ELECTR			0x08000000  // 0x00000008 
#define DIA_MEM_CHKSUM			0x10000000  // 0x00000010 
#define DIA_MEASUREMENT			0x20000000  // 0x00000020 
#define DIA_NOT_INIT			0x40000000  // 0x00000040 
#define DIA_INIT_ERR			0x80000000  // 0x00000080 
#define DIA_ZERO_ERR			0x00010000  // 0x00000100 
#define DIA_SUPPLY				0x00020000  // 0x00000200 
#define DIA_CONF_INVAL			0x00040000  // 0x00000400 
#define DIA_WARMSTART			0x00080000  // 0x00000800 
#define DIA_COLDSTART			0x00100000  // 0x00001000 
#define DIA_MAINTENANCE			0x00200000  // 0x00002000 
#define DIA_CHARACT				0x00400000  // 0x00004000 
#define DIA_IDENT_VIOL			0x00800000  // 0x00008000 
#define EXTENSION_AVAILABLE		0x00000080  // 0x80000000 

#define DEF_DISPLAY_FORMAT_PV_SP(value)					\
		SELECT(SCALdp)									\
		{												\
			CASE 0:		".0f";							\
			CASE 1:		".1f";							\
			CASE 2:		".2f";							\
			CASE 3:		".3f";							\
		}												\

#define FUNC1_DEFAULT_UNIT						1349


/*******************************************************************************/
/*****	MENU Bar  **************************************************************/
/*******************************************************************************/

MENU Menu_Main_Specialist
{
	LABEL		[main_menu];
	ITEMS
	{
		Menu_File,
		Menu_S_Device,
		Menu_View,
		Menu_Options,
		Menu_Help
	}
}

MENU Menu_Main_Maintenance
{
	LABEL		[main_menu];
	ITEMS
	{
		Menu_File,
		Menu_M_Device,
		Menu_View,
		Menu_Options,
		Menu_Help
	}
}

/*******************************************************************************/
/*****	MENU Device  ***********************************************************/
/*******************************************************************************/

MENU Menu_S_Device
{
	LABEL		[menu_Device];
	ITEMS
	{
		std_NodeAddress,
		SEPARATOR,
		std_LoadinDevice,
		std_LoadinPC,
		SEPARATOR,
		OnlineDialog_operation,
		OnlineDialog_self_calibration,
		OnlineDialog_Safety_Position,
		OnlineDialog_PCON,
		OnlineDialog_reset
	}
}

MENU Menu_M_Device
{
	LABEL		[menu_Device];
	ITEMS
	{
		std_LoadinDevice,										
		std_LoadinPC,
		SEPARATOR,
		OnlineDialog_operation,
		Page_reset_m
	}
}


/*******************************************************************************/
/*****	MENU View  *************************************************************/
/*******************************************************************************/

MENU Menu_View
{
	LABEL		[menu_View];
	ITEMS
	{
        OnlineWindow_display,
		std_Funktionsleiste,
		std_Statuszeile
		
	}
}

MENU OnlineWindow_display
{
        LABEL           [menu_dialog_display];
        ITEMS
        {
                Page_display_measure,
                Page_display_out
        }
}

MENU Page_display_measure
{
        LABEL           [menu_dialog_display_measure];
        ITEMS
        {
                BarVal_display_readback,
                BarVal_display_setpoint,
				BarVal_display_temp
        }
}

MENU BarVal_display_readback
{
        LABEL           [txt_PV];
        ITEMS
        {
                PV,
                PVmin              (READ_ONLY),
                PVmax              (READ_ONLY)
        }
}

MENU BarVal_display_setpoint
{
        LABEL           [txt_SP];
        ITEMS
        {
                SP,
                SPmin              (READ_ONLY),
                SPmax              (READ_ONLY)
        }
}

MENU BarVal_display_temp
{
        LABEL           [txt_FEEDBACK_VALUE];
        ITEMS
        {
				FEEDBACK_VALUE,
				limit_min_2			(READ_ONLY),
				limit_max_2			(READ_ONLY)

        }
}

MENU Page_display_out
{
	LABEL		[menu_table_data];
	ITEMS
	{
		SETP_DEVIATION,
		PV,
		TEMP,
		XTUNE_STATUS
	}
}


/*******************************************************************************/
/*****	Variablen   ************************************************************/
/*******************************************************************************/
 
#include "BUDP_AC_879x_var.inc"

/*******************************************************************************/
/*****	Kommandos   ************************************************************/
/*******************************************************************************/
 
#include "BUDP_AC_879x_com.inc"

/*******************************************************************************/
/*****	MENU Table  ************************************************************/
/*******************************************************************************/

MENU Table_Main_Specialist
{
	LABEL	DEVICE_TITLE ;
	ITEMS
	{
		Tab_s_ident,
		Tab_s_setpoint,
		Tab_s_actuator,
		Tab_s_prozessregler,
		Tab_s_sicherheit,
		Tab_s_diagnostics
	}
}

MENU Table_Main_Maintenance
{
	LABEL	DEVICE_TITLE ;
	ITEMS
	{
		Tab_m_ident,
		Tab_m_setpoint,
		Tab_m_actuator,
		Tab_m_prozessregler,
		Tab_m_sicherheit,
		Tab_m_diagnostics
	}
}

/*******************************************************************************/
/*****	MENU Table  Spezialist	************************************************/
/*******************************************************************************/

MENU Tab_s_ident
{
	LABEL		[menu_ident];

	ITEMS
	{
		Tab_s_ident_opunit
	}
}

MENU Tab_s_ident_opunit
{
	LABEL		[menu_ident_opunit];
	ITEMS
	{
		phys_DEVICE_MAN_ID,
		phys_IDENT_NUMBER,
		phys_tag_desc
	}
}

MENU Tab_s_setpoint
{
	LABEL		[menu_table_setpoint];
	ITEMS
	{
		POSITIONING_VALUE		(READ_ONLY),
		mPCONsetp,
		PCON					(READ_ONLY),
		MODE1					(READ_ONLY)
	}
}

MENU Tab_s_actuator
{
	LABEL		[menu_table_actuator];
	ITEMS
	{
		INCREASE_CLOSE		(READ_ONLY),
		DEADBAND,
		ACT_STROKE_TIME_INC,
		ACT_STROKE_TIME_INC_LOC,
		ACT_STROKE_TIME_DEC,
		ACT_STROKE_TIME_DEC_LOC,
		LIN_TYPE,
		TRAVEL_LIMIT_LOW,
		TRAVEL_LIMIT_UP,
		TRAVEL_RATE_INC,
		TRAVEL_RATE_DEC,
		SERVO_GAIN_1,
		SERVO_GAIN_2
	}
}

MENU Tab_s_prozessregler
{
	LABEL		[menu_table_prozessregler];
	ITEMS
	{
		mPCONinp,
		DBDp,
		KP,
		TN,
		TV,
		X0,
		FTfgPV,
		SCALunit,
		SCALdp,
		SCALdp_LOC			(HIDDEN),
		PVmin,
		PVmin_Loc,
		PVmax,
		PVmax_Loc,
		SPmin,
		SPmin_Loc,
		SPmax,
		SPmax_Loc
	}
}

MENU Tab_s_sicherheit
{
	LABEL		[menu_table_sicherheit];
	ITEMS
	{
		SETP_CUTOFF_DEC,
		SETP_CUTOFF_INC,
		mCUTOFFtype,
		mSAFEpos	(READ_ONLY),
		mBUSfail_func,
		mERRpinp_func,
		mSPOSpinp_func
	}
}

MENU Tab_s_diagnostics
{
	LABEL		[menu_table_diagnostics];
	ITEMS
	{
		ERROR_8792_8793,
		DIAGNOSIS,
		XTUNE_STATUS
	}
}

MENU OnlineDialog_self_calibration
{
        LABEL  [txt_SELF_Calibration];
        HELP   [txt_help_SELF_Calibration];
        ITEMS
        {
                self_calibration
        }
}

MENU self_calibration
{
        LABEL  [txt_SELF_Calibration];
        HELP   [txt_help_SELF_Calibration];
        ITEMS
        {
			SELF_CALIB_CMD,
			MODE1	(READ_ONLY)
        }
}

MENU OnlineDialog_Safety_Position
{
        LABEL  [txt_menu_Safety_Position];
        HELP   [txt_help_menu_Safety_Position];
        ITEMS
        {
                menu_Safety_Position
        }
}

MENU menu_Safety_Position
{
        LABEL  [txt_menu_Safety_Position];
        HELP   [txt_help_menu_Safety_Position];
        ITEMS
        {
			mSAFEpos,
			method_mSAFEpos
        }
}

MENU OnlineDialog_reset
{
        LABEL           [master_reset];
        HELP            [master_reset_help];
        ITEMS
        {
                Page_reset
        }
}

MENU OnlineDialog_reset_m
{
        LABEL           [master_reset];
        HELP            [master_reset_help];
        ITEMS
        {
                Page_reset_m
        }
}

MENU Page_reset
{
        LABEL           [master_reset];
        HELP            [master_reset_help];
        ITEMS
        {
                method_phys_factory_reset_params,
                method_phys_factory_reset_warm
        }
}

MENU Page_reset_m
{
        LABEL           [master_reset];
        HELP            [master_reset_help];
        ITEMS
        {
                method_phys_factory_reset_warm
        }
}

MENU OnlineDialog_operation
{
        LABEL           [txt_MODE];
        ITEMS
        {
                Page_operation
        }
}

MENU Page_operation
{
        LABEL           [txt_MODE];
        ITEMS
        {
			MODE1
        }
}

MENU OnlineDialog_PCON
{
		LABEL         [txt_PCON];
		HELP          [txt_help_PCON];
        ITEMS
        {
			PCON		(READ_ONLY),
		    method_activated,
			method_deactivated
        }
}

/*******************************************************************************/
/*****	MENU Table  Instandhalter	****************************************/
/*******************************************************************************/

MENU Tab_m_ident
{
	LABEL		[menu_ident];

	ITEMS
	{
		Tab_m_ident_opunit
	}
}

MENU Tab_m_ident_opunit
{
	LABEL		[menu_ident_opunit];
	ITEMS
	{
		phys_DEVICE_MAN_ID,
		phys_IDENT_NUMBER,
		phys_tag_desc
	}
}

MENU Tab_m_setpoint
{
	LABEL		[menu_table_setpoint];
	ITEMS
	{
		POSITIONING_VALUE			(READ_ONLY),
		mPCONsetp					(READ_ONLY),
		PCON						(READ_ONLY),
		MODE1						(READ_ONLY)
	}	
}

MENU Tab_m_actuator
{
	LABEL		[menu_table_actuator];
	ITEMS
	{
		INCREASE_CLOSE				(READ_ONLY),
		DEADBAND					(READ_ONLY),
		ACT_STROKE_TIME_INC			(READ_ONLY),
		ACT_STROKE_TIME_INC_LOC		(READ_ONLY),
		ACT_STROKE_TIME_DEC			(READ_ONLY),
		ACT_STROKE_TIME_DEC_LOC		(READ_ONLY),
		LIN_TYPE					(READ_ONLY),
		TRAVEL_LIMIT_LOW			(READ_ONLY),
		TRAVEL_LIMIT_UP				(READ_ONLY),
		TRAVEL_RATE_INC				(READ_ONLY),
		TRAVEL_RATE_DEC				(READ_ONLY),
		SERVO_GAIN_1				(READ_ONLY),
		SERVO_GAIN_2				(READ_ONLY)
	}
}

MENU Tab_m_prozessregler
{
	LABEL		[menu_table_prozessregler];
	ITEMS
	{
		mPCONinp,
		DBDp						(READ_ONLY),
		KP							(READ_ONLY),
		TN							(READ_ONLY),
		TV							(READ_ONLY),
		X0							(READ_ONLY),
		FTfgPV						(READ_ONLY),
		SCALunit					(READ_ONLY),
		SCALdp						(READ_ONLY),
		SCALdp_LOC					(HIDDEN),
		PVmin						(READ_ONLY),
		PVmin_Loc					(READ_ONLY),
		PVmax						(READ_ONLY),
		PVmax_Loc					(READ_ONLY),
		SPmin						(READ_ONLY),
		SPmin_Loc					(READ_ONLY),
		SPmax						(READ_ONLY),
		SPmax_Loc					(READ_ONLY)
	}
}

MENU Tab_m_sicherheit
{
	LABEL		[menu_table_sicherheit];
	ITEMS
	{
		SETP_CUTOFF_DEC				(READ_ONLY),
		SETP_CUTOFF_INC				(READ_ONLY),
		mCUTOFFtype					(READ_ONLY),
		mSAFEpos					(READ_ONLY),
		mBUSfail_func				(READ_ONLY),
		mERRpinp_func				(READ_ONLY),
		mSPOSpinp_func				(READ_ONLY)
	}
}

MENU Tab_m_diagnostics
{
	LABEL		[menu_table_diagnostics];
	ITEMS
	{
		ERROR_8792_8793				(READ_ONLY),
		DIAGNOSIS					(READ_ONLY),
		XTUNE_STATUS
	}
}

/*******************************************************************************/
/*****	Methods		********************************************************/
/*******************************************************************************/


/******************************************************************************/
/*****      Standard Methods  *************************************************/
/******************************************************************************/
METHOD std_NodeAddress
{
	LABEL		[menu_Device_NodeAddress];
	DEFINITION
	{
	}
}
/********************************************************/
METHOD std_LoadinDevice
{
      LABEL            [menu_Device_LoadinDevice];
      CLASS            INPUT;
      DEFINITION
      {
      }
}
/********************************************************/
METHOD std_LoadinPC
{
      LABEL            [menu_Device_LoadinPC];
      CLASS            INPUT;
      DEFINITION
      {
      }
}
/********************************************************/
METHOD std_Funktionsleiste
{
      LABEL            [menu_View_Toolbar];
      CLASS            INPUT;
      DEFINITION
      {
      }
}
/********************************************************/
METHOD std_Statuszeile
{
      LABEL            [menu_View_Statusbar];
      CLASS            INPUT;
      DEFINITION
      {
      }
}
/********************************************************/
METHOD std_Update
{
      LABEL            [menu_View_Update];
      DEFINITION
      {
      }
}


/******************************************************************************/
/*****      Benutzerdefinierte  Methoden  *************************************/
/******************************************************************************/
METHOD method_activated
{
      LABEL            [txt_method_activated];
      DEFINITION
      {
                int status;

				status = ReadCommand(read_MODE1);

				if (MODE1 == 0) 
				{
					status = ReadCommand(read_PCON);

					PCON = 1 ; //aktiviert
					
					status = WriteCommand(write_PCON);

					PCON = 0 ; //deaktiviert

					status = WriteCommand(write_PCON);
					
					status = ReadCommand(read_PCON);

					PCON = 1 ; //aktiviert
					
					status = WriteCommand(write_PCON);
				}
				else
				{
					ACKNOWLEDGE([txt_change_MODE]);

				}
      }
}

METHOD method_deactivated
{
      LABEL            [txt_method_deactivated];
      DEFINITION
      {
                int status;

				status = ReadCommand(read_MODE1);

				if (MODE1 == 0) 
				{
				status = ReadCommand(read_PCON);
	
				PCON = 0 ; //deaktiviert
				
				status = WriteCommand(write_PCON);
				}
				else
				{
					ACKNOWLEDGE([txt_change_MODE]);

				}

      }
}

/*******************************************************/
   METHOD method_mSAFEpos
{
		 LABEL [txt_Safety_Position];

		 DEFINITION
		 {
                int status;
                int choice;
                char text1[];
                char text2[];
		 		 		 		 int iLen ;
		 		 		 		 iLen = 512;		 		 

                get_dictionary_string(no, text1);
                get_dictionary_string(yes, text2);
                text1 = text1 + ";" + text2;

                choice = SELECT_FROM_LIST(
                "Really change Safety Position?"
                "|de|Mchten Sie wirklich die Sicherheitsposition ndern?"
                , text1);

                if ( choice == 0 )  // change -> no
                {

                }
		 		 		 		 else    // change -> yes
                {
		 		 		         status = WriteCommand(write_mSAFEpos);

		                 get_dictionary_string(no, text1);
		 		 		 		 		 get_dictionary_string(yes, text2);
		 		 		 		 		 text1 = text1 + ";" + text2;

		 		 		 		 		 choice = SELECT_FROM_LIST(
		 		 		 		 		 "Do you want to de-activate Safety Position?"
		 		 		 		 		 "|de|Soll die Sicherheitsposition deaktiviert werden?"
		 		 		 		 		 , text1);

		 		 		 		 		 if ( choice == 0 )  // abschlieen -> no
		 		 		 		 		 {
		 		 		 		 		 		 		 		 		 		 		 }
		 		 		 		 		 else		 		 		 		 // abschlieen -> yes
		 		 		 		 		 {
		 		 		 		 		 
                              ACKNOWLEDGE("Instead of moving to Safety Position, the air from the actuator will be exhausted in Safety Mode. |de|Anstelle die Position anzufahren, wird der Antrieb im Sicherheitsmodus entlftet");		 
                              mSAFEpos = -1;
                        status = WriteCommand(write_mSAFEpos);
		 		 		 		 		 }
                }
        }
}    


/*******************************************************/

METHOD method_phys_factory_reset_params
{
        LABEL           [factory_reset_PARAMS];
        DEFINITION
        {
                int status;
                int choice;
                char text1[];
                char text2[];

                get_dictionary_string(no, text1);
                get_dictionary_string(yes, text2);
                text1 = text1 + ";" + text2;

                choice = SELECT_FROM_LIST(
                "All settings currently stored in the device will overwritten by factory "
                "default data.  Do you really want to load factory defaults ?"
                "|de|Alle Einstellungen des Gertes werden berschrieben durch Werksdaten. "
                "Mchten Sie fortfahren ?"
                , text1);

                if ( choice == 0 )  // keine Werksdaten laden -> no
                {

                }
				else   // Werksdaten laden -> yes
                {
                        ACKNOWLEDGE([txt_factory_reset_PARAMS]);
                        ACKNOWLEDGE([txt_factory_reset_PARAMS_2]);
                        FACTORY_RESET = 2; //      [FACTORY_RESET]

                        status = WriteCommand(write_FACTORY_RESET);

                }
        }
}

/*******************************************************/

METHOD method_phys_factory_reset_warm
{
        LABEL           [phys_device_reset_cmd];
        DEFINITION
        {
                int status;
                int choice;
                char text1[];
                char text2[];
				int iLen ;
				iLen = 512;		

                get_dictionary_string(no, text1);
                get_dictionary_string(yes, text2);
                text1 = text1 + ";" + text2;
                choice = SELECT_FROM_LIST(
                "Caution!!!  Selecting yes will perform a software reset on device. The fail safe function "
                "may cause a hazardous movement of the actuator.  Communication will be re-established "
                "automatically.  This may take some seconds!\r\n"
                "Really reset device?\r\n"
                "|de|Das Gert fhrt einen Software-Reset aus.  Die Sicherheitsstellung wird dabei angefahren, "
                "was zu einer unvorhergesehenen Bewegung des Antriebs fhren kann.\r\n"
                "Mchten Sie wirklich einen Reset ausfhren?\r\n"
                , text1);

                if ( choice == 0 )  // kein Reset -> no
                {

                }
				else    // Reset -> yes
                {
                        FACTORY_RESET = 1 ;   // warm start

                        status = WriteCommand(write_FACTORY_RESET);

						if( status == 17456 )
						{
							ACKNOWLEDGE([not_supported]) ;
						}

                }
        }
}

/*******************************************************/

METHOD method_upload_variables_PRE_WRITE
{
        LABEL           "txt_method_upload_variables_PRE_WRITE";
        DEFINITION
        {
                int status;

                status = ReadCommand(read_MODE);

                status = ReadCommand(read_mPCONinp);
				
				status = ReadCommand(read_PCON);

		}
}

/*******************************************************************************/
/*****	Commands  **************************************************************/
/*******************************************************************************/


MENU download_variables			//lesen aus dem Gert
{
	LABEL		[menu_load_to_PC];
	ITEMS
	{
		ERROR_8792_8793,
		MODE1,
		DIAGNOSIS,
		FACTORY_RESET,
		ACT_STROKE_TIME_INC,
		ACT_STROKE_TIME_DEC,
		DEADBAND,
		LIN_TYPE,
		SELF_CALIB_CMD,
		SERVO_GAIN_1,
		SERVO_GAIN_2,
		SETP_CUTOFF_DEC,
		SETP_CUTOFF_INC,
		TRAVEL_LIMIT_LOW,
		TRAVEL_LIMIT_UP,
		TRAVEL_RATE_DEC,
		TRAVEL_RATE_INC,
		POSITIONING_VALUE,
		FEEDBACK_VALUE,
		SETP_DEVIATION,
		INCREASE_CLOSE,
		SP,
		PV,
		TEMP,
		PCON,
		DBDp,
		KP,
		TN,
		TV,
		X0,
		mPCONsetp,
		mPCONinp,
		FTfgPV,
		SCALunit,
		SCALdp,
		PVmin,
		PVmax,
		SPmin,
		SPmax,
		mCUTOFFtype,
		mBUSfail_func,
		mERRpinp_func,
		mSPOSpinp_func,
		mSAFEpos,
		XTUNE_STATUS
	}
}

MENU upload_variables			// schreiben in das Gert
{
    LABEL           [menu_load_to_device];
	ITEMS
	{
				IF (MODE1 == 0)
				{
					PCON
				}

				IF (MODE1 == 0 || MODE1 == 1)
				{
					ERROR_8792_8793,
					FACTORY_RESET,
					DEADBAND,
					LIN_TYPE,
					SELF_CALIB_CMD,
					SERVO_GAIN_1,
					SERVO_GAIN_2,
					SETP_CUTOFF_DEC,
					SETP_CUTOFF_INC,
					TRAVEL_LIMIT_LOW,
					TRAVEL_LIMIT_UP,
					TRAVEL_RATE_DEC,
					TRAVEL_RATE_INC,
					INCREASE_CLOSE
					DBDp,
					KP,
					TN,
					TV,
					X0,
					mPCONsetp,
					FTfgPV,
					SCALdp,
					PVmin,
					PVmax,
					SPmin,
					SPmax,
					mCUTOFFtype,
					mBUSfail_func,
					mSAFEpos
				}


				IF ((MODE1 == 0 || MODE1 == 1 ) && (mPCONinp == 2 || mPCONinp == 3))
				{
					SCALunit
				}

				IF ((MODE1 == 0 || MODE1 == 1 ) && (mPCONinp == 0 || mPCONinp == 1 || mPCONinp == 3) && (PCON == 1))
				{
					mERRpinp_func,
					mSPOSpinp_func
				}
				
	}
	PRE_WRITE_ACTIONS
	{
			method_upload_variables_PRE_WRITE
	}

}

/*
0 == ohne alles
1 == (MODE1 == 0)
2 == (MODE1 == 0 || MODE1 == 1 )
3 == (MODE1 == 0 || MODE1 == 1 ) && (mPCONinp == 0)
4 == (MODE1 == 0 || MODE1 == 1 ) && (mPCONinp == 2 || mPCONinp == 3)
5 == (MODE1 == 0 || MODE1 == 1 ) && (mPCONinp == 0 || mPCONinp == 1 || mPCONinp == 3)

*/



/***********************************************************************/
/*    Unit relations                                                   */
/***********************************************************************/
 
UNIT UNIT_PV_SP
{
	SCALunit:  
	PVmin_Loc,
	PVmax_Loc,
	SPmin_Loc, 
	SPmax_Loc
}
